summaryrefslogtreecommitdiff
path: root/app/Report/ReportParserBase.php
diff options
context:
space:
mode:
authorGreg Roach <greg@subaqua.co.uk>2021-08-20 13:01:11 +0100
committerGreg Roach <greg@subaqua.co.uk>2021-08-20 13:06:46 +0100
commit8792b649b8d6c79391f005a1a18587383a7f7856 (patch)
tree7387d71692136e88ddda19a96281dd07b7c1aa57 /app/Report/ReportParserBase.php
parent4a8d2484af6774d65f5b58408932f697b73fa5aa (diff)
downloadwebtrees-8792b649b8d6c79391f005a1a18587383a7f7856.tar.gz
webtrees-8792b649b8d6c79391f005a1a18587383a7f7856.tar.bz2
webtrees-8792b649b8d6c79391f005a1a18587383a7f7856.zip
CodeStyle
Diffstat (limited to 'app/Report/ReportParserBase.php')
-rw-r--r--app/Report/ReportParserBase.php3
1 files changed, 2 insertions, 1 deletions
diff --git a/app/Report/ReportParserBase.php b/app/Report/ReportParserBase.php
index 1c2786a240..7a34eca3fd 100644
--- a/app/Report/ReportParserBase.php
+++ b/app/Report/ReportParserBase.php
@@ -21,6 +21,7 @@ namespace Fisharebest\Webtrees\Report;
use DomainException;
use Exception;
+use XMLParser;
use function call_user_func;
use function fclose;
@@ -46,7 +47,7 @@ use const XML_OPTION_CASE_FOLDING;
*/
class ReportParserBase
{
/** @var resource The XML parser */
protected $xml_parser;
/** @var string Text contents of tags */
@@ -46,7 +47,7 @@ use const XML_OPTION_CASE_FOLDING;
class ReportParserBase
{
- /** @var resource The XML parser */
+ /** @var resource|XMLParser The XML parser */
protected $xml_parser;
/** @var string Text contents of tags */